@@ -1,7 +1,7 @@
-__submodules__ = ["bids"]
+__submodules__ = ["core"]
 
 # <AUTOGEN_INIT>
-from snakebids.bids import (
+from snakebids.core import (
     bids,
     filter_list,
     generate_inputs,
