@@ -7,6 +7,7 @@ from pathlib import Path
 from typing import Any, Dict, List, Optional
 
 import attr
+import boutiques.creator as bc
 import snakemake
 from colorama import Fore
 from snakemake.io import load_configfile
@@ -220,6 +221,11 @@ class SnakeBidsApp:
             ]
         )
 
+    def create_descriptor(self, out_file):
+        """Generate a boutiques descriptor for this Snakebids app."""
+        new_descriptor = bc.CreateDescriptor(self.parser, execname="run.py")
+        new_descriptor.save(out_file)
+
 
 def update_config(config: Dict[str, Any], snakebids_args: SnakebidsArgs):
     # add snakemake arguments to config
